@@ -1,9 +1,9 @@
-import python_minifier.ast_compat as ast
 import sys
 
+import python_minifier.ast_compat as ast
+
 from .expression_printer import ExpressionPrinter
 from .token_printer import Delimiter
-from .util import is_ast_node
 
 
 class ModulePrinter(ExpressionPrinter):
@@ -28,11 +28,15 @@ class ModulePrinter(ExpressionPrinter):
         assert isinstance(module, ast.Module)
 
         self.visit_Module(module)
-        return str(self.printer).rstrip('\n' + self.indent_char + ';')
+        # On Python 2.7, preserve unicode strings to avoid encoding issues
+        code = unicode(self.printer) if sys.version_info[0] < 3 else str(self.printer)
+        return code.rstrip('\n' + self.indent_char + ';')
 
     @property
     def code(self):
-        return str(self.printer).rstrip('\n' + self.indent_char + ';')
+        # On Python 2.7, preserve unicode strings to avoid encoding issues
+        code = unicode(self.printer) if sys.version_info[0] < 3 else str(self.printer)
+        return code.rstrip('\n' + self.indent_char + ';')
 
     # region Simple Statements
 
@@ -55,7 +59,7 @@ class ModulePrinter(ExpressionPrinter):
     def visit_Expr(self, node):
         assert isinstance(node, ast.Expr)
 
-        if is_ast_node(node.value, (ast.Yield, 'YieldFrom')):
+        if isinstance(node.value, (ast.Yield, ast.YieldFrom)):
             self._yield_expr(node.value)
         else:
             self._testlist(node.value)
@@ -82,7 +86,7 @@ class ModulePrinter(ExpressionPrinter):
             self.printer.delimiter('=')
 
         # Yield nodes that are the sole node on the right hand side of an assignment do not need parens
-        if is_ast_node(node.value, (ast.Yield, 'YieldFrom')):
+        if isinstance(node.value, (ast.Yield, ast.YieldFrom)):
             self._yield_expr(node.value)
         else:
             self._testlist(node.value)
@@ -97,7 +101,7 @@ class ModulePrinter(ExpressionPrinter):
         self.printer.delimiter('=')
 
         # Yield nodes that are the sole node on the right hand side of an assignment do not need parens
-        if is_ast_node(node.value, (ast.Yield, 'YieldFrom')):
+        if isinstance(node.value, (ast.Yield, ast.YieldFrom)):
             self._yield_expr(node.value)
         else:
             self._testlist(node.value)
@@ -143,7 +147,7 @@ class ModulePrinter(ExpressionPrinter):
 
         self.printer.keyword('return')
         if isinstance(node.value, ast.Tuple):
-            if sys.version_info < (3, 8) and [n for n in node.value.elts if is_ast_node(n, 'Starred')]:
+            if sys.version_info < (3, 8) and [n for n in node.value.elts if isinstance(n, ast.Starred)]:
                 self.printer.delimiter('(')
                 self._testlist(node.value)
                 self.printer.delimiter(')')
@@ -243,7 +247,7 @@ class ModulePrinter(ExpressionPrinter):
         assert isinstance(node, ast.ImportFrom)
 
         self.printer.keyword('from')
-        for i in range(node.level):
+        for _i in range(node.level):
             self.printer.delimiter('.')
         if node.module is not None:
             self.printer.identifier(node.module)
@@ -326,7 +330,7 @@ class ModulePrinter(ExpressionPrinter):
                 self._suite(node.orelse)
 
     def visit_For(self, node, is_async=False):
-        assert isinstance(node, ast.For) or (hasattr(ast, 'AsyncFor') and isinstance(node, ast.AsyncFor))
+        assert isinstance(node, (ast.For, ast.AsyncFor))
 
         self.printer.newline()
 
@@ -362,7 +366,7 @@ class ModulePrinter(ExpressionPrinter):
             self._suite(node.orelse)
 
     def visit_Try(self, node, star=False):
-        assert is_ast_node(node, (ast.Try, 'TryStar'))
+        assert isinstance(node, (ast.Try, ast.TryStar))
 
         self.printer.newline()
         self.printer.keyword('try')
@@ -440,7 +444,7 @@ class ModulePrinter(ExpressionPrinter):
         self._suite(node.body)
 
     def visit_With(self, node, is_async=False):
-        assert is_ast_node(node, (ast.With, 'AsyncWith'))
+        assert isinstance(node, (ast.With, ast.AsyncWith))
 
         self.printer.newline()
 
@@ -469,7 +473,7 @@ class ModulePrinter(ExpressionPrinter):
         self._suite(node.body)
 
     def visit_withitem(self, node):
-        assert is_ast_node(node, ('withitem', ast.With))
+        assert isinstance(node, (ast.withitem, ast.With))
 
         self._expression(node.context_expr)
 
@@ -478,7 +482,7 @@ class ModulePrinter(ExpressionPrinter):
             self._expression(node.optional_vars)
 
     def visit_FunctionDef(self, node, is_async=False):
-        assert is_ast_node(node, (ast.FunctionDef, 'AsyncFunctionDef'))
+        assert isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef))
 
         self.printer.newline()
 
@@ -670,7 +674,7 @@ class ModulePrinter(ExpressionPrinter):
         for kwd, pattern in zip(node.kwd_attrs, node.kwd_patterns):
             delimiter.new_item()
 
-            self.printer.identifier(kwd)    
+            self.printer.identifier(kwd)
             self.printer.delimiter('=')
 
             self.pattern(pattern)
@@ -859,4 +863,3 @@ class ModulePrinter(ExpressionPrinter):
 
         for node in node_list:
             statements[node.__class__.__name__](node)
-
