@@ -1,17 +1,23 @@
 import ast
 import sys
+
 import pytest
 
-from python_minifier import add_namespace, RemoveAnnotationsOptions
-from python_minifier.transforms.remove_annotations import RemoveAnnotations
+from python_minifier import RemoveAnnotationsOptions
+from python_minifier.ast_annotation import add_parent
 from python_minifier.ast_compare import compare_ast
+from python_minifier.rename import add_namespace
+from python_minifier.transforms.remove_annotations import RemoveAnnotations
+
 
 def remove_annotations(source, **kwargs):
     module = ast.parse(source)
+    add_parent(module)
     add_namespace(module)
     RemoveAnnotations(RemoveAnnotationsOptions(**kwargs))(module)
     return module
 
+
 def test_AnnAssign():
 
     if sys.version_info < (3, 6):
@@ -32,13 +38,16 @@ class A:
     a: int'''
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=True,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=False)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=True,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=False
+    )
     compare_ast(expected_ast, actual_ast)
 
+
 def test_FunctionDef():
     if sys.version_info < (3,):
         pytest.skip('Annotation unsupported in python < 3.0')
@@ -50,11 +59,13 @@ def test_FunctionDef():
     pass'''
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=True,
-                                    remove_argument_annotations=True,
-                                    remove_class_attribute_annotations=False)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=True,
+        remove_argument_annotations=True,
+        remove_class_attribute_annotations=False
+    )
     compare_ast(expected_ast, actual_ast)
 
     # args only are removed
@@ -64,11 +75,13 @@ def test_FunctionDef():
     pass'''
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=True,
-                                    remove_class_attribute_annotations=False)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=True,
+        remove_class_attribute_annotations=False
+    )
     compare_ast(expected_ast, actual_ast)
 
     # return only are removed
@@ -84,9 +97,10 @@ def test_FunctionDef():
         remove_return_annotations=True,
         remove_argument_annotations=False,
         remove_class_attribute_annotations=False
-        )
+    )
     compare_ast(expected_ast, actual_ast)
 
+
 def test_AsyncFunctionDef():
     if sys.version_info < (3, 6):
         pytest.skip('Async function unsupported in python < 3.5')
@@ -97,13 +111,16 @@ def test_AsyncFunctionDef():
     pass'''
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=True,
-                                    remove_return_annotations=True,
-                                    remove_argument_annotations=True,
-                                    remove_class_attribute_annotations=False)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=True,
+        remove_return_annotations=True,
+        remove_argument_annotations=True,
+        remove_class_attribute_annotations=False
+    )
     compare_ast(expected_ast, actual_ast)
 
+
 def test_AnnAssign_novalue():
     if sys.version_info < (3, 6):
         pytest.skip('Variable annotation unsupported in python < 3.6')
@@ -120,13 +137,16 @@ class A:
 '''
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=True,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=False)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=True,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=False
+    )
     compare_ast(expected_ast, actual_ast)
 
+
 def test_class_attributes():
     if sys.version_info < (3, 6):
         pytest.skip('Variable annotation unsupported in python < 3.6')
@@ -145,11 +165,13 @@ class A:
 '''
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=True)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=True
+    )
     compare_ast(expected_ast, actual_ast)
 
 
@@ -184,13 +206,16 @@ class MyClass:
     expected = source
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=True)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=True
+    )
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_dataclass():
     if sys.version_info < (3, 6):
         pytest.skip('annotations unavailable in python < 3.6')
@@ -211,11 +236,13 @@ class MyClass:
     mysecondfile: 0
 '''
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=True)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=True
+    )
     compare_ast(expected_ast, actual_ast)
 
 
@@ -239,13 +266,16 @@ class MyClass2(blah.NamedTuple):
     expected = source
 
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=True)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=True
+    )
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove():
     if sys.version_info < (3, 6):
         pytest.skip('annotations unavailable in python < 3.6')
@@ -269,11 +299,13 @@ class Dummy(typing.NermedTupel):
     mysecondfile: 0
 '''
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=True)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=True
+    )
     compare_ast(expected_ast, actual_ast)
 
 
@@ -302,24 +334,26 @@ class Dummy(typing.TypedDic):
 class Dummy(TypedDict):
     myfield: int
     mysecondfile: str
-    
+
 class Dummy(HypedDict):
     myfield: 0
-    mysecondfile: 0    
+    mysecondfile: 0
 
 class Dummy(typing.TypedDict):
     myfield: int
     mysecondfile: str
-    
+
 class Dummy(typing.TypedDic):
     myfield: 0
     mysecondfile: 0
-        
+
 '''
     expected_ast = ast.parse(expected)
-    actual_ast = remove_annotations(source,
-                                    remove_variable_annotations=False,
-                                    remove_return_annotations=False,
-                                    remove_argument_annotations=False,
-                                    remove_class_attribute_annotations=True)
+    actual_ast = remove_annotations(
+        source,
+        remove_variable_annotations=False,
+        remove_return_annotations=False,
+        remove_argument_annotations=False,
+        remove_class_attribute_annotations=True
+    )
     compare_ast(expected_ast, actual_ast)
